@@ -27,11 +27,13 @@ no warnings _disabled_warnings();
 use B::Hooks::AtRuntime 'after_runtime';
 use Import::Into;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub import {
     my ( $class, %args ) = @_;
+    my @caller = caller(0);
     $args{_import_type} = 'class';
+    $args{_caller_eval} = ( $caller[1] =~ /^\(eval/ );    # https://github.com/Ovid/moosex-extreme/pull/34
     my $target_class = _assert_import_list_is_valid( $class, \%args );
     my @with_meta    = grep { not $args{excludes}{$_} } qw(field param);
     if (@with_meta) {
@@ -70,7 +72,7 @@ sub _apply_default_features ( $config, $for_class, $params = undef ) {
         say STDERR "We are running under the debugger or using code that uses debugger code (e.g., Devel::Cover). $for_class is not immutable";
     }
     else {
-        unless ( $config->{excludes}{immutable} ) {
+        unless ( $config->{excludes}{immutable} or $config->{_caller_eval} ) {    # https://github.com/Ovid/moosex-extreme/pull/34
 
             # after_runtime is loaded too late under the debugger
             eval {
@@ -92,10 +94,10 @@ sub _apply_default_features ( $config, $for_class, $params = undef ) {
             };
         }
     }
-    unless ( $config->{excludes}{true} ) {
+    unless ( $config->{excludes}{true} or $config->{_caller_eval} ) {    # https://github.com/Ovid/moosex-extreme/pull/34
         eval {
             load true;
-            true->import::into($for_class);    # no need for `1` at the end of the module
+            true->import::into($for_class);                              # no need for `1` at the end of the module
             1;
         } or do {
             my $error = $@;
@@ -125,7 +127,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -414,9 +416,10 @@ See the L<MooseX::Extended::Manual::Cloning> documentation.
 
 =head1 OBJECT CONSTRUCTION
 
-Objection construction for L<MooseX::Extended> is like Moose, so no
-changes are needed.  However, in addition to C<has>, we also provide C<param>
-and C<field> attributes, both of which are C<< is => 'ro' >> by default.
+Object construction for L<MooseX::Extended> is identical to Moose because
+MooseX::Extended I<is> Moose, so no changes are needed.  However, in addition
+to C<has>, we also provide C<param> and C<field> attributes, both of which are
+C<< is => 'ro' >> by default.
 
 The C<param> is I<required>, whether by passing it to the constructor, or using
 C<default> or C<builder>.
@@ -466,6 +469,16 @@ When using C<field> or C<param>, we have some attribute shortcuts:
         ...
     }
 
+You can also do this:
+
+    param name ( isa => NonEmptyStr, builder => sub {...} );
+
+That's the same as:
+
+    param name ( isa => NonEmptyStr, builder => '_build_name' );
+
+    sub _build_name {...}
+
 See L<MooseX::Extended::Manual::Shortcuts> for a full explanation.
 
 =head1 INVALID ATTRIBUTE DEFINITIONS
@@ -507,6 +520,8 @@ relies on L<B::Hooks::AtRuntime>'s C<after_runtime> function. However, that
 runs too late under the debugger and dies. Thus, we disable this feature under
 the debugger. Your classes may run a bit slower, but hey, it's the debugger!
 
+There is L<a PR against B::Hooks::AtRuntime which will fix this issue|https://github.com/mauzo/B-Hooks-AtRuntime/pull/1>.
+
 =item * C<namespace::autoclean> will frustrate you
 
 It's very frustrating when running under the debugger and doing this:
@@ -520,10 +535,20 @@ backed that out: L<https://github.com/Ovid/moosex-extreme/issues/11>.
 
 =back
 
+=head1 BUGS AND LIMITATIONS
+
+If the MooseX::Extended classes are loaded via I<stringy> eval, C<true> is not
+loaded, nor is your class made immutable. This is because there were
+intermittant errors (maybe 1 out of 5 times) being thrown. Removing these
+features under stringy eval solves this. See L<this github ticket for more
+infomration|https://github.com/Ovid/moosex-extreme/pull/34>.
+
 =head1 MANUAL
 
 =over 4
 
+=item * L<MooseX::Extended::Manual::Tutorial>
+
 =item * L<MooseX::Extended::Manual::Overview>
 
 =item * L<MooseX::Extended::Manual::Construction>
