@@ -13,11 +13,12 @@ use MooseX::Extended::Core qw(
 use MooseX::Extended ();
 use namespace::autoclean;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub import {
-    my $custom_moose = caller;    # this is our custom Moose definition
-    true->import::into($custom_moose);
+    my @caller       = caller(0);
+    my $custom_moose = $caller[0];    # this is our custom Moose definition
+    true->import::into($custom_moose) unless $caller[1] =~ /^\(eval/;
     strict->import::into($custom_moose);
     warnings->import::into($custom_moose);
     namespace::autoclean->import::into($custom_moose);
@@ -27,7 +28,7 @@ sub import {
 
 sub create {
     my ( $class, %args ) = @_;
-    my $target_class = caller(1);    # this is the class consuming our custom Moose
+    my $target_class = caller(1);     # this is the class consuming our custom Moose
     MooseX::Extended->import(
         %args,
         call_level => 1,
@@ -49,7 +50,7 @@ MooseX::Extended::Custom - Build a custom Moose, just for you.
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
